==> spring-cloud-netflix-eureka-client-4.0.2-sources.jar: org/springframework/cloud/netflix/eureka/http/RestTemplateTransportClientFactories.java <==
/*
 * Copyright 2017-2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.netflix.eureka.http;

import java.util.Collection;
import java.util.Optional;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLContext;

import com.netflix.appinfo.InstanceInfo;
import com.netflix.discovery.EurekaClientConfig;
import com.netflix.discovery.shared.transport.TransportClientFactory;
import com.netflix.discovery.shared.transport.jersey.TransportClientFactories;

/**
 * @author Daniel Lavoie
 */
public class RestTemplateTransportClientFactories implements TransportClientFactories<Void> {

	private final RestTemplateDiscoveryClientOptionalArgs args;

	public RestTemplateTransportClientFactories(RestTemplateDiscoveryClientOptionalArgs args) {
		this.args = args;
	}

	@Override
	public TransportClientFactory newTransportClientFactory(EurekaClientConfig clientConfig,
			Collection<Void> additionalFilters, InstanceInfo myInstanceInfo) {
		return new RestTemplateTransportClientFactory(this.args.getSSLContext(), this.args.getHostnameVerifier(),
				this.args.eurekaClientHttpRequestFactorySupplier);
	}

	@Override
	public TransportClientFactory newTransportClientFactory(final EurekaClientConfig clientConfig,
			final Collection<Void> additionalFilters, final InstanceInfo myInstanceInfo,
			final Optional<SSLContext> sslContext, final Optional<HostnameVerifier> hostnameVerifier) {
		return new RestTemplateTransportClientFactory(this.args.getSSLContext(), this.args.getHostnameVerifier(),
				this.args.eurekaClientHttpRequestFactorySupplier);
	}

}

==> spring-cloud-netflix-eureka-client-4.1.5-sources.jar: org/springframework/cloud/netflix/eureka/http/RestTemplateTransportClientFactories.java <==
/*
 * Copyright 2017-2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.netflix.eureka.http;

import java.util.Collection;
import java.util.Optional;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLContext;

import com.netflix.appinfo.InstanceInfo;
import com.netflix.discovery.EurekaClientConfig;
import com.netflix.discovery.shared.transport.TransportClientFactory;
import com.netflix.discovery.shared.transport.jersey.TransportClientFactories;

/**
 * @author Daniel Lavoie
 * @author Armin Krezovic
 */
public class RestTemplateTransportClientFactories implements TransportClientFactories<Void> {

	private final RestTemplateDiscoveryClientOptionalArgs args;

	public RestTemplateTransportClientFactories(RestTemplateDiscoveryClientOptionalArgs args) {
		this.args = args;
	}

	@Override
	public TransportClientFactory newTransportClientFactory(EurekaClientConfig clientConfig,
			Collection<Void> additionalFilters, InstanceInfo myInstanceInfo) {
		return new RestTemplateTransportClientFactory(this.args.getSSLContext(), this.args.getHostnameVerifier(),
				this.args.eurekaClientHttpRequestFactorySupplier, this.args.restTemplateBuilderSupplier);
	}

	@Override
	public TransportClientFactory newTransportClientFactory(final EurekaClientConfig clientConfig,
			final Collection<Void> additionalFilters, final InstanceInfo myInstanceInfo,
			final Optional<SSLContext> sslContext, final Optional<HostnameVerifier> hostnameVerifier) {
		return new RestTemplateTransportClientFactory(this.args.getSSLContext(), this.args.getHostnameVerifier(),
				this.args.eurekaClientHttpRequestFactorySupplier, this.args.restTemplateBuilderSupplier);
	}

}
